*********************************************************************************
*Prepares munnicipality level temperature and precipitation means for five
*countries examined in Table 3
*********************************************************************************
capture log close
clear
set mem 200000
cd "INSERT YOUR DIRECTORY PATH HERE"

/* Data files used
			pre`Y'`X'.dbf
			max`Y'`X'.dbf
			min`Y'`X'.dbf			
			where X=1/12 (data are by months)
						Y=BR MX PM US VE (FIPS country identifiers); produced by aej_climate.py

			BRcensus3.csv
			UScensus3.csv (The admin codes for Brazil and the U.S. that are
					used by the IPUMS income data are too long for
					Arcgis to handle as a zone field. Thus, the python file aej_boundaries.py
					assigns municipality ids to these countries of the form 1,2,... These two
					.csv files merge back in the admin codes used in the income data.)


	Data files produced as final product
			climBR, climMX, climPM, climUS, climVE (country-by-country files with
					municipality level mean temperature and precipitation)
*/
						
			
***----Import data from dbf files 

**--Precipiation
foreach X of num 1/12 {
	foreach Y in BR MX PM US VE {
		odbc load VALUE MEAN, table("pre`Y'`X'.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		summ admin3
		rename mean lpre3
		replace lpre3=lpre3/10 /*precip in centimeters*/
		summ lpre3
		gen month=`X'
		sort admin3
		save pre`X'`Y', replace
		clear
	}
}

**--Max tem
foreach X of num 1/12 {
	foreach Y in BR MX PM US VE {
		odbc load VALUE MEAN, table("max`Y'`X'.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		summ admin3
		rename mean lmax3
		replace lmax3=lmax3/10 /*unit of measure in gis data is degrees celsius*10 */
		summ lmax3
		gen month=`X'
		sort admin3
		save max`X'`Y', replace
		clear
	}
}


**--Min tem
foreach X of num 1/12 {
	foreach Y in BR MX PM US VE {
		odbc load VALUE MEAN, table("min`Y'`X'.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		summ admin3
		rename mean lmin3
		replace lmin3=lmin3/10 /*unit of measure in gis data is degrees celsius*10 */
		summ lmin3
		gen month=`X'
		sort admin3
		save min`X'`Y', replace
		clear
	}
}

**Merge months
foreach Y in BR MX PM US VE {
	use pre1`Y'
	foreach X of num 2/12 {
		append using pre`X'`Y'
	}
	collapse (sum) lpre3, by(admin3) /*total annual precip*/
	save pre`Y', replace
	
	use min1`Y'
	foreach X of num 2/12 {
		append using min`X'`Y'
	}
	collapse (mean) lmin3, by(admin3) /*mean annual min. temperature*/
	save min`Y', replace
	
	use max1`Y'
	foreach X of num 2/12 {
		append using max`X'`Y'
	}
	collapse (mean) lmax3, by(admin3) /*mean annual max. temperature*/
	save max`Y', replace
	
	mmerge admin3 using min`Y', type(1:1)
	mmerge admin3 using pre`Y', type(1:1)
	gen ltem3=(lmax3+lmin3)/2 /*mean annual average temperature*/
	summ ltem3 lpre3
	drop lmax3 lmin3 _merge
	gen cntry="`Y'"
	sort admin3
	save clim`Y', replace
}


***--------get admin identifiers for Brazil and U.S.

clear
insheet using BRcensus3.csv
rename cid admin3
mmerge admin3 using climBR, type(1:1)
drop admin3 _merge
rename  br3codes_a admin3
save climBR, replace

clear
insheet using UScensus3.csv
rename cid admin3
mmerge admin3 using climUS, type(1:1)
drop admin3 _merge
rename mun admin3
save climUS, replace


***--------prepare admin codes so that equivalent to those in income data

use climBR, clear
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 1, 2)
rename temp admin3
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save climBR, replace

use climMX, clear
replace admin3=admin3+100000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 3)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
sort admin1 admin3
save climMX, replace


use climPM, clear
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
sort admin1 admin3
save climPM, replace

use climUS, clear
replace admin3=admin3+1000000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 4)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save climUS, replace


use climVE, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save climVE, replace










