*********************************************************************************
*Prepares terrain data at the municipality level - by country - 
*that will be used for calculating partial correlations between incomes and
*proximity to roads
*********************************************************************************
capture log close
clear
set mem 200000
cd "INSERT DIRECTORY PATH HERE"
log using aej_elevslope, replace

/* Files used as inputs
			e3BR.dbf e3MX.dbf e3PM.dbf e3US.dbf e3VE.dbf 
			s3BR.dbf s3MX.dbf s3PM.dbf s3US.dbf s3VE.dbf (all produced by aej_elevslope.py)
			BRcensus3.csv
			UScensus3.csv
			VEcensus3.csv  (The admin codes for Brazil, the U.S., and Venezuela that are
					used by the IPUMS income data are too long for
					Arcgis to handle as a zone field. Thus, the python file aej_boundaries.py
					assigns municipality ids to these countries of the form 1,2,... These two
					.csv files merge back in the admin codes used in the income data.)

Final data files produced
			terrainBR.dta terrainMX.dta terrainPM.dta terrainUS.dta terrainVE.dta 
					(country files with municipality-level terrain data)
*/

***-------Import data from dbf files 
foreach X in BR MX PM US VE {

		odbc load VALUE MEAN, table("e3`X'.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		rename mean elev3
		label var elev3 "municipality (3rd level admin) elevation (m)"
		save temp, replace
		clear
		
		odbc load VALUE MEAN, table("s3`X'.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		rename mean slope3
		label var slope3 "municipality (3rd level admin) slope (degrees)"
		mmerge admin3 using temp, type(1:1)
		drop _merge
		summ slope3 elev3
		save terrain`X', replace
		clear		
}


****------get admin identifiers for Brazil, Venezuela, and U.S.

insheet using BRcensus3.csv
rename cid admin3
mmerge admin3 using terrainBR, type(1:1)
drop admin3 _merge
rename  br3codes_a admin3
save terrainBR, replace

clear
insheet using UScensus3.csv
rename cid admin3
mmerge admin3 using terrainUS, type(1:1)
drop admin3 _merge
rename mun admin3
save terrainUS, replace


clear
insheet using VEcensus3.csv
rename cid admin3
mmerge admin3 using terrainVE, type(1:1)
drop admin3 _merge
rename ve3codes_c admin3
save terrainVE, replace



***--------prepare admin codes so that equivalent to those in income data

use terrainBR, clear
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 1, 2)
rename temp admin3
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save terrainBR, replace

use terrainMX, clear
replace admin3=admin3+100000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 3)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
sort admin1 admin3
save terrainMX, replace


use terrainPM, clear
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
sort admin1 admin3
save terrainPM, replace

use terrainUS, clear
replace admin3=admin3+1000000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 4)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save terrainUS, replace


use terrainVE, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save terrainVE, replace

