#---------------------------------------------------------------------------
# This file calculates mean elev and slope, weighted by landmass area, 
# for third level admin means (census data countries)
# ---------------------------------------------------------------------------

# Import system modules
import sys, string, os, arcgisscripting, shutil 

# Create the Geoprocessor object
gp = arcgisscripting.create()

# Check out any necessary licenses
gp.CheckOutExtension("spatial")

# Load required toolboxes...
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Analysis Tools.tbx")
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Spatial Analyst Tools.tbx")
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Conversion Tools.tbx")
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/3D Analyst Tools.tbx")
gp.AddToolbox("C:/Program Files/ArcGIS/ArcToolbox/Toolboxes/Data Management Tools.tbx")

#Turn overwrite on
gp.overwriteoutput = 1
print "overwrite on"

# Set directory path
gp.workspace = "INSERT DIRECTORY PATH HERE"
print "directroy set"


#---Merge elev tiles together
# Local variables...
elev = "elev"
W180S10_DEM = "W180S10.DEM"
W140S10_DEM = "W140S10.DEM"
W180N40_DEM = "W180N40.DEM"
W060N90_DEM = "W060N90.DEM"
w060n40_DEM = "w060n40.DEM"
W060S10_DEM = "W060S10.DEM"
W100N40_DEM = "W100N40.DEM"
W100N90_DEM = "W100N90.DEM"
W100S10_DEM = "W100S10.DEM"
W140N40_DEM = "W140N40.DEM"
W140N90_DEM = "W140N90.DEM"
W180N90_DEM = "W180N90.DEM"
growth_empirics = "INSERT DIRECTORY PATH HERE"

# The files beginning with "W" are the elevation tiles from http://www.dgadv.com/srtm30/

# Process: Mosaic To New Raster...
gp.MosaicToNewRaster_management("W180S10.DEM; W140S10.DEM; W180N40.DEM; W060N90.DEM; w060n40.dem;W060S10.DEM;W100N40.DEM;W100N90.DEM;W100S10.DEM;W140N40.DEM;W140N90.DEM;W180N90.DEM", growth_empirics, "elev", "GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]", "8_BIT_UNSIGNED", "", "1", "LAST", "FIRST")

######################
###--------elev
######################


#---Note: typically when calculating areas within polygons, one would
#---want to project the data to an equal area coordinate system.
#---However, municipalities are so small that very little distortion
#---is introduced taking avareges with the data in a geographic
#---coordinate system, and more error in fact may be introduced
#---by resampling the raster in order to project it. Hence, I calculate
#---averages with all layers in WGS1984.


##-----Brazil

# Process: Zonal Statistics as Table ...
BRcensus3="BRcensus3.shp"
el3BR="el3BR"
gp.ZonalStatisticsAsTable_sa(BRcensus3, "cid", elev, el3BR, "DATA")
print "BR admin 3 population elev means completed" 
        
# Process: Table Select...
el3BR_dbf="e3BR.dbf"
gp.TableSelect_analysis(el3BR, el3BR_dbf, "")
print "BR admin 3 population elev means exported"


##-----Mexico

# Process: Zonal Statistics as Table ...
MXcensus3="MXcensus3.shp"
el3MX="el3MX"
gp.ZonalStatisticsAsTable_sa(MXcensus3, "MXcodes_AD", elev, el3MX, "DATA")
print "MX admin 3 population elev means completed" 
        
# Process: Table Select...
el3MX_dbf="e3MX.dbf"
gp.TableSelect_analysis(el3MX, el3MX_dbf, "")
print "MX admin 3 population elev means exported"


##-----Panama

# Process: Zonal Statistics as Table ...
PMcensus3="PMcensus3.shp"
el3PM="el3PM"
gp.ZonalStatisticsAsTable_sa(PMcensus3, "PMcodes.ADMIN3", elev, el3PM, "DATA")
print "PM admin 3 population elev means completed" 
        
# Process: Table Select...
el3PM_dbf="e3PM.dbf"
gp.TableSelect_analysis(el3PM, el3PM_dbf, "")
print "PM admin 3 population elev means exported"


##-----United States

# Process: Zonal Statistics as Table ...
UScensus3="UScensus3.shp"
el3US="el3US"
gp.ZonalStatisticsAsTable_sa(UScensus3, "cid", elev, el3US, "DATA")
print "US admin 3 population elev means completed" 
        
# Process: Table Select...
el3US_dbf="e3US.dbf"
gp.TableSelect_analysis(el3US, el3US_dbf, "")
print "US admin 3 population elev means exported"


##-----Venezuela



# Process: Zonal Statistics as Table ...
VEcensus3_shp = "VEcensus3.shp"
VEel = "\VEel"
gp.ZonalStatisticsAsTable_sa(VEcensus3_shp, "cid", elev, VEel, "DATA")
print "ve admin 3 population elev means completed" 
        
# Process: Table Select...
el3VE_dbf="e3VE.dbf"
gp.TableSelect_analysis(VEel, el3VE_dbf, "")
print "veadmin 3 population elev means exported"




#########################
##-----Slopes
#########################


# Process: Slope...
slope="slope"
elev_prj="elev_prj"
gp.Slope_sa(elev_prj, slope, "DEGREE", "1")
print "calculated slope"





####---------Project country boundaries

# Local variables...
BRcensus3_prj_shp = "BRcensus3_prj.shp"
MXcensus3_prj_shp = "MXcensus3_prj.shp"
PMcensus3_prj_shp = "PMcensus3_prj.shp"
UScensus3_prj_shp = "UScensus3_prj.shp"
VEcensus3_prj_shp = "VEcensus3_prj.shp"
BRcensus3_shp = "BRcensus3.shp"
MXcensus3_shp = "MXcensus3.shp"
PMcensus3_shp = "PMcensus3.shp"
UScensus3_shp = "UScensus3.shp"
VEcensus3_shp = "VEcensus3.shp"

# Process: Project...
gp.Project_management(BRcensus3_shp, BRcensus3_prj_shp, "PROJCS['World_Cylindrical_Equal_Area',GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]],PROJECTION['Cylindrical_Equal_Area'],PARAMETER['False_Easting',0.0],PARAMETER['False_Northing',0.0],PARAMETER['Central_Meridian',0.0],PARAMETER['Standard_Parallel_1',0.0],UNIT['Meter',1.0]]", "", "GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]")

# Process: Project (2)...
gp.Project_management(MXcensus3_shp, MXcensus3_prj_shp, "PROJCS['World_Cylindrical_Equal_Area',GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]],PROJECTION['Cylindrical_Equal_Area'],PARAMETER['False_Easting',0.0],PARAMETER['False_Northing',0.0],PARAMETER['Central_Meridian',0.0],PARAMETER['Standard_Parallel_1',0.0],UNIT['Meter',1.0]]", "", "GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]")

# Process: Project (3)...
gp.Project_management(PMcensus3_shp, PMcensus3_prj_shp, "PROJCS['World_Cylindrical_Equal_Area',GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]],PROJECTION['Cylindrical_Equal_Area'],PARAMETER['False_Easting',0.0],PARAMETER['False_Northing',0.0],PARAMETER['Central_Meridian',0.0],PARAMETER['Standard_Parallel_1',0.0],UNIT['Meter',1.0]]", "", "GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]")

# Process: Project (4)...
gp.Project_management(UScensus3_shp, UScensus3_prj_shp, "PROJCS['World_Cylindrical_Equal_Area',GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]],PROJECTION['Cylindrical_Equal_Area'],PARAMETER['False_Easting',0.0],PARAMETER['False_Northing',0.0],PARAMETER['Central_Meridian',0.0],PARAMETER['Standard_Parallel_1',0.0],UNIT['Meter',1.0]]", "", "GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]")

# Process: Project (5)...
gp.Project_management(VEcensus3_shp, VEcensus3_prj_shp, "PROJCS['World_Cylindrical_Equal_Area',GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]],PROJECTION['Cylindrical_Equal_Area'],PARAMETER['False_Easting',0.0],PARAMETER['False_Northing',0.0],PARAMETER['Central_Meridian',0.0],PARAMETER['Standard_Parallel_1',0.0],UNIT['Meter',1.0]]", "", "GEOGCS['GCS_WGS_1984',DATUM['D_WGS_1984',SPHEROID['WGS_1984',6378137.0,298.257223563]],PRIMEM['Greenwich',0.0],UNIT['Degree',0.0174532925199433]]")




###-----Brazil

# Process: Zonal Statistics as Table ...
sl3BR="sl3BR"
gp.ZonalStatisticsAsTable_sa(BRcensus3_prj_shp, "cid", slope, sl3BR, "DATA")
"BR population elev means completed" 
        
# Process: Table Select...
sl3BR_dbf="s3BR.dbf"
gp.TableSelect_analysis(sl3BR, sl3BR_dbf, "")
print "BR population elev means exported"



###-----Mexico

# Process: Zonal Statistics as Table ...
sl3MX="sl3MX"
gp.ZonalStatisticsAsTable_sa(MXcensus3_prj_shp, "MXcodes_AD", slope, sl3MX, "DATA")
"MX population elev means completed" 
        
# Process: Table Select...
sl3MX_dbf="s3MX.dbf"
gp.TableSelect_analysis(sl3MX, sl3MX_dbf, "")
print "MX population elev means exported"



###-----Panama

# Process: Zonal Statistics as Table ...
sl3PM="sl3PM"
gp.ZonalStatisticsAsTable_sa(PMcensus3_prj_shp, "PMcodes.ADMIN3", slope, sl3PM, "DATA")
"PM population elev means completed" 
        
# Process: Table Select...
sl3PM_dbf="s3PM.dbf"
gp.TableSelect_analysis(sl3PM, sl3PM_dbf, "")
print "PM population elev means exported"



###-----United States

# Process: Zonal Statistics as Table ...
sl3US="sl3US"
gp.ZonalStatisticsAsTable_sa(UScensus3_prj_shp, "cid", slope, sl3US, "DATA")
"US population elev means completed" 
        
# Process: Table Select...
sl3US_dbf="s3US.dbf"
gp.TableSelect_analysis(sl3US, sl3US_dbf, "")
print "US population elev means exported"



###-----Venezuela

# Process: Zonal Statistics as Table ...
sl3VE="sl3VE"
gp.ZonalStatisticsAsTable_sa(VEcensus3_prj_shp, "cid", slope, sl3VE, "DATA")
"ve population elev means completed" 
        
# Process: Table Select...
sl3VE_dbf="s3VE.dbf"
gp.TableSelect_analysis(sl3VE, sl3VE_dbf, "")
print "ve population elev means exported"
