*********************************************************************************
*Prepares population data at the municipality or region level - by country - 
*that will be used for weighting the inequality comparisons
*********************************************************************************
capture log close
clear
set mem 200000
cd "INSERT DIRECTORY PATH HERE"
log using aej_pop00, replace

/* Files used as inputs
	BLp.dbf BRp.dbf CAp.dbf CIp.dbf COp.dbf ECp.dbf ESp.dbf GTp.dbf HOp.dbf
		 MXp.dbf PAp.dbf PMp.dbf USp.dbf UYp.dbf VEp.dbf (all produced by aej_pop00.py)
			BRcensus3.csv
			UScensus3.csv  (The admin codes for Brazil and the U.S.  that are
					used by the IPUMS income data are too long for
					Arcgis to handle as a zone field. Thus, the python file aej_boundaries.py
					assigns municipality ids to these countries of the form 1,2,... These two
					.csv files merge back in the admin codes used in the income data.)

Final data files produced
	pop00BL.dta pop00BR.dta pop00CA.dta pop00CI.dta pop00CO.dta pop00EC.dta pop00ES.dta 
		pop00GT.dta pop00HO.dta pop00MX.dta pop00PA.dta pop00PM.dta pop00US.dta pop00UY.dta 
		pop00VE.dta (country files with municipality-level population data)

*/

***-------Import data from dbf files 
foreach X in BL BR CA CI CO EC ES GT HO MX PA PM US UY VE {

		odbc load VALUE SUM, table("`X'p.dbf") dsn("dBASE Files") lowercase
		rename value admin3
		rename sum pop00
		label var pop00 "population (2000)"
		save pop00`X', replace
		clear
}

odbc load CODIGO_DIS SUM, table("PEp.dbf") dsn("dBASE Files") lowercase
rename codigo_dis admin3
rename sum pop00
label var pop00 "population (2000)"
save pop00PE, replace
clear

***------get admin identifiers for Brazil and U.S.

insheet using BRcensus3.csv
rename cid admin3
mmerge admin3 using pop00BR, type(1:1)
drop admin3 _merge
rename  br3codes_a admin3
save pop00BR, replace

clear
insheet using UScensus3.csv
rename cid admin3
mmerge admin3 using pop00US, type(1:1)
drop admin3 _merge
rename mun admin3
save pop00US, replace


***---Create separate identifier codes for first and third level administrative units

use pop00BL, clear
drop if admin3==0 /*water bodies*/
drop if pop00==0 /*water bodies*/
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 1, 1)
gen admin3=substr(temp, 2, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00BL, replace

use pop00BR, clear
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 1, 2)
rename temp admin3
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00BR, replace


use pop00CA, clear
drop if admin3==0 /*water body*/
rename admin3 admin1
sort admin1
save pop00CA, replace

use pop00CI, clear
rename admin3 admin1
sort admin1
save pop00CI, replace

use pop00CO, clear
rename admin3 admin1
sort admin1
save pop00CO, replace

use pop00EC, clear
rename admin3 admin1
sort admin1
save pop00EC, replace

use pop00ES, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00ES, replace


use pop00GT, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00GT, replace


use pop00HO, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00HO, replace


use pop00MX, clear
replace admin3=admin3+100000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 3)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00MX, replace


use pop00PA, clear
drop if admin3<0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
replace admin3=1 if admin1==0 /*Asuncion*/
tab admin1
summ admin3
sort admin1 admin3
save pop00PA, replace


use pop00PE, clear
destring admin3, replace
replace admin3=admin3+1000000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin2=substr(temp, 4, 2)
gen admin3=substr(temp, 6, 2)
drop temp
destring admin1, replace
destring admin2, replace
destring admin3, replace
drop if admin1==. /*water body*/
tab admin1
tab admin2
summ admin3
sort admin1 admin2 admin3
save pop00PE, replace


use pop00PM, clear
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00PM, replace


use pop00US, clear
replace admin3=admin3+1000000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 4)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00US, replace


use pop00UY, clear
drop if admin3==0 /*water bodies*/
rename admin3 admin1
sort admin1
save pop00UY, replace


use pop00VE, clear
drop if admin3==0 /*water bodies*/
replace admin3=admin3+10000
tostring admin3, g(temp)
drop admin3
gen admin1=substr(temp, 2, 2)
gen admin3=substr(temp, 4, 2)
drop temp
destring admin1, replace
destring admin3, replace
tab admin1
summ admin3
sort admin1 admin3
save pop00VE, replace



		